%{
/*
 * Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */
#include <stdio.h>
#include <opensm/osm_file_ids.h>
#define FILE_ID OSM_FILE_TENANT_PARSER_L_L
#include <opensm/osm_tenant_mgr.h>
#include "osm_tenant_parser_y.h"

extern char *__tenant_parser_yylval;


%}

NUMBER		(0x[0-9a-fA-F]+|[1-9]+[0-9]*|[0-7]+)
BOOLEAN		(true|false|TRUE|FALSE|True|False)

%option nounput noinput noyywrap
%option yylineno


%%

[ \t]+			{ /* ignore whitespace */                                       }
[\n]			{ /* ignore newlines */                                         }
\#.*\n			{ /* ignore comments */                                         }
[:]			{                                    return COLON;              }
"map-group"		{                                    return MAP_GROUP;          }
"name"			{                                    return NAME;               }
"max_tenant_mc_groups"	{                                    return MAX_MC_GROUPS;      }
"tenant_vport_lids"	{				     return TENANT_VPORT_LIDS;	}
"end-map-group"		{                                    return END_MAP_GROUP;      }
"physical-port-guid"	{                                    return PHYSICAL_PORT_GUID; }
"virtual-port-guid"	{                                    return VIRTUAL_PORT_GUID;  }
[,]			{                                    return COMMA;              }
{NUMBER}		{ __tenant_parser_yylval = yytext;   return NUMBER;             }
{BOOLEAN}		{ __tenant_parser_yylval = yytext;   return BOOLEAN;		}
.			{                                    return ERROR;              }

%%
